Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java')
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java92
1 files changed, 44 insertions, 48 deletions
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java
index e013e37969c..bb49539fd32 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/infrastructure/elements/EAElement.java
@@ -17,6 +17,7 @@ package org.eclipse.papyrus.eastadl.infrastructure.elements;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
+import org.eclipse.uml2.uml.Comment;
import org.eclipse.uml2.uml.NamedElement;
@@ -25,109 +26,104 @@ import org.eclipse.uml2.uml.NamedElement;
* <!-- begin-user-doc -->
* A representation of the model object '<em><b>EA Element</b></em>'.
* <!-- end-user-doc -->
- *
+ *
* <!-- begin-model-doc -->
- * The EAElement is an abstract metaclass that represents an arbitrary named entity in the domain model. It specializes AUTOSAR Identifiable which has
- * the shortName attribute used for identification of the element within the namespace in which it is defined.
+ * The EAElement is an abstract metaclass that represents an arbitrary named entity in the domain model. It specializes AUTOSAR Identifiable which has the shortName attribute used for identification of the element within the namespace in which it is defined.
*
* The abbreviation EA in the name of this metaclass is short for EAST-ADL.
*
*
* Semantics:
- * Also the EAElement can be used to extend the EAST-ADL2 approach to other languages and standards by adding a generalize relation from the
- * respective (non EAST-ADL2) element to the EAElement.
+ * Also the EAElement can be used to extend the EAST-ADL2 approach to other languages and standards by adding a generalize relation from the respective (non EAST-ADL2) element to the EAElement.
*
*
* Changes:
* New class in EAST-ADL2
*
- * Extension:
+ * Extension:
* The EAElement stereotype is an abstract stereotype
* <!-- end-model-doc -->
- *
+ *
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getName <em>Name</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getBase_NamedElement <em>Base Named Element</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getOwnedComment <em>Owned Comment</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getBase_NamedElement <em>Base Named Element</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getName <em>Name</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getOwnedComment <em>Owned Comment</em>}</li>
* </ul>
* </p>
- *
+ *
* @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement()
* @model abstract="true"
* @generated
*/
public interface EAElement extends EObject {
-
/**
- * Returns the value of the '<em><b>Name</b></em>' attribute.
+ * Returns the value of the '<em><b>Base Named Element</b></em>' reference.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Name</em>' attribute isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Base Named Element</em>' reference isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Name</em>' attribute.
- * @see #setName(String)
- * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_Name()
- * @model unique="false" dataType="org.eclipse.uml2.types.String" transient="true" volatile="true" derived="true" ordered="false"
+ * @return the value of the '<em>Base Named Element</em>' reference.
+ * @see #setBase_NamedElement(NamedElement)
+ * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_Base_NamedElement()
+ * @model required="true" ordered="false"
* @generated
*/
- String getName();
+ NamedElement getBase_NamedElement();
/**
- * Returns the value of the '<em><b>Owned Comment</b></em>' reference list.
- * The list contents are of type {@link org.eclipse.papyrus.eastadl.infrastructure.elements.Comment}.
+ * Sets the value of the '{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getBase_NamedElement <em>Base Named Element</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Owned Comment</em>' reference list.
- * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_OwnedComment()
- * @model ordered="false"
+ * @param value the new value of the '<em>Base Named Element</em>' reference.
+ * @see #getBase_NamedElement()
* @generated
*/
- EList<Comment> getOwnedComment();
+ void setBase_NamedElement(NamedElement value);
/**
- * Returns the value of the '<em><b>Base Named Element</b></em>' reference.
+ * Returns the value of the '<em><b>Name</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Base Named Element</em>' reference isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Name</em>' attribute isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Base Named Element</em>' reference.
* @see #setBase_NamedElement(NamedElement)
* @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_Base_NamedElement()
* @model required="true" ordered="false"
* @generated
*/
- NamedElement getBase_NamedElement();
+ String getName();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getBase_NamedElement <em>Base Named Element</em>}'
- * reference.
+ * Sets the value of the '{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getName <em>Name</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Base Named Element</em>' reference.
- * @see #getBase_NamedElement()
+ * @param value the new value of the '<em>Name</em>' attribute.
+ * @see #getName()
* @generated
*/
- void setBase_NamedElement(NamedElement value);
+ void setName(String value);
/**
- * Sets the value of the '{@link org.eclipse.papyrus.eastadl.infrastructure.elements.EAElement#getName <em>Name</em>}' attribute.
+ * Returns the value of the '<em><b>Owned Comment</b></em>' reference list.
+ * The list contents are of type {@link org.eclipse.uml2.uml.Comment}.
* <!-- begin-user-doc -->
+ * <p>
+ * If the meaning of the '<em>Owned Comment</em>' reference list isn't clear,
+ * there really should be more of a description here...
+ * </p>
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Name</em>' attribute.
- * @see #getName()
+ * @return the value of the '<em>Owned Comment</em>' reference list.
+ * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_OwnedComment()
+ * @model ordered="false"
* @generated
*/
- void setName(String value);
+ EList<Comment> getOwnedComment();
} // EAElement

Back to the top
@@ -25,109 +26,104 @@ import org.eclipse.uml2.uml.NamedElement;
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Base Named Element</em>' reference.
- * @see #setBase_NamedElement(NamedElement)
- * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_Base_NamedElement()
- * @model required="true" ordered="false"
+ * @return the value of the '<em>Name</em>' attribute.
+ * @see #setName(String)
+ * @see org.eclipse.papyrus.eastadl.infrastructure.elements.ElementsPackage#getEAElement_Name()
+ * @model dataType="org.eclipse.uml2.types.String" transient="true" volatile="true" derived="true" ordered="false"
* @generated
*/